@@ -13,6 +13,7 @@ from requests.exceptions import HTTPError, JSONDecodeError
 import archimedes
 from archimedes.auth import archimedes_auth, NoneAuth
 from archimedes.configuration import api_config
+from archimedes.data.types import Prediction, PredictionData
 
 API_URL = api_config.url
 API_VERSION = 2
@@ -265,7 +266,6 @@ def get(
             )
 
     df.index = pd.to_datetime(df.index)
-    df = df.fillna("")
     return df
 
 
@@ -624,6 +624,50 @@ def store_prediction(
     )
 
     return ret.get("success", False)
+    
+
+def store_predictions(
+    prediction_id: str,
+    prediction_data: List[PredictionData],
+    *,
+    access_token: str = None,
+):
+    """Store a prediction
+
+    Example:
+        >>> import archimedes
+        >>> import pandas as pd
+        >>> from dateutil.tz import gettz
+        >>> tz_oslo = gettz("Europe/Oslo")
+        >>> prediction_id = "test-prediction-id"
+        >>> from_dt = pd.Timestamp("2021-04-11 23:47:16.854775807", tz=tz_oslo)
+        >>> ref_dt = pd.Timestamp("2021-04-10 23:00:00.000000000", tz=tz_oslo)
+        >>> run_dt = pd.Timestamp.now(tz=tz_oslo)
+        >>> data = {"direction": "D", "probability": 0.8632089971077396, "hours_ahead": 1, "price_area": "NO1"}
+        >>> prediction_data = [{'from_dt': from_dt, 'ref_dt': ref_dt, 'run_dt': run_dt, 'data': data }]
+        >>> archimedes.store_predictions(
+        >>>     prediction_id=prediction_id,
+        >>>     prediction_data=prediction_data
+        >>> )
+        True
+    """
+
+    predictions = [{"from_dt": p["from_dt"].isoformat(), "ref_dt": p["ref_dt"].isoformat(), "run_dt": p["run_dt"].isoformat(), "data": p["data"]} for p in prediction_data]
+
+    payload = {
+        "prediction_id": prediction_id,
+        "data": predictions,
+    }
+
+    ret = _make_api_request(
+        f"{API_URL}/v{API_VERSION}/data/store_predictions",
+        method="POST",
+        data=json.dumps(payload),
+        headers={"Content-Type": "application/json"},
+        access_token=access_token,
+    )
+
+    return ret.get("success", False)
 
 
 def forecast_list_ref_times(
